==> fred_webwhois-3.0.0-py3-none-any.whl: webwhois/urls.py <==
#
# Copyright (C) 2015-2023  CZ.NIC, z. s. p. o.
#
# This file is part of FRED.
#
# FRED is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# FRED is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with FRED.  If not, see <https://www.gnu.org/licenses/>.
#
from django.urls import path
from django.views.i18n import JavaScriptCatalog
from fred_types import RegistryObjectType

from webwhois.views import (BlockObjectFormView, ContactDetailView, DomainDetailView, DownloadEvalFileView,
                            EmailInRegistryView, KeysetDetailView, NssetDetailView, PersonalInfoFormView,
                            PublicResponseNotFoundView, PublicResponsePdfView, PublicResponseView, RegistrarDetailView,
                            RegistrarListView, ResolveHandleTypeView, ScanResultsView, SendPasswordFormView,
                            ServeRecordStatementView, UnblockObjectFormView, WhoisFormView)

app_name = 'webwhois'
urlpatterns = [
    path('', WhoisFormView.as_view(), name='form_whois'),
    path('jsi18n/<packages>/', JavaScriptCatalog.as_view(), name='jsi18n'),
    path('object/<handle>/', ResolveHandleTypeView.as_view(), name='registry_object_type'),
    path('contact/<handle>/', ContactDetailView.as_view(), name='detail_contact'),
    path('nsset/<handle>/', NssetDetailView.as_view(), name='detail_nsset'),
    path('keyset/<handle>/', KeysetDetailView.as_view(), name='detail_keyset'),
    path('domain/<handle>/', DomainDetailView.as_view(), name='detail_domain'),
    path('domain/<handle>/scan-results/', ScanResultsView.as_view(), name='scan_results'),
    path('registrar/<handle>/', RegistrarDetailView.as_view(), name='detail_registrar'),
    path('registrars/', RegistrarListView.as_view(), name='registrars'),
    path('registrar-download-evaluation-file/<handle>/', DownloadEvalFileView.as_view(),
         name='download_evaluation_file'),
    path('send-password/', SendPasswordFormView.as_view(), name='form_send_password'),
    path('personal-info/', PersonalInfoFormView.as_view(), name='form_personal_info'),
    path('block-object/', BlockObjectFormView.as_view(), name='form_block_object'),
    path('unblock-object/', UnblockObjectFormView.as_view(), name='form_unblock_object'),
    path('public-response/<public_key>/', PublicResponseView.as_view(), name='public_response'),
    path('public-response/<public_key>/pdf/', PublicResponsePdfView.as_view(), name='public_response_pdf'),
    path('response-not-found/<public_key>/', PublicResponseNotFoundView.as_view(), name='response_not_found'),
    path('email-in-registry/<public_key>/', EmailInRegistryView.as_view(), name='email_in_registry_response'),
    path('verified-record-statement-pdf/contact/(<handle>)/', ServeRecordStatementView.as_view(),
         name='record_statement_pdf', kwargs={"object_type": RegistryObjectType.CONTACT}),
    path('verified-record-statement-pdf/domain/(<handle>)/', ServeRecordStatementView.as_view(),
         name='record_statement_pdf', kwargs={"object_type": RegistryObjectType.DOMAIN}),
    path('verified-record-statement-pdf/keyset/(<handle>)/', ServeRecordStatementView.as_view(),
         name='record_statement_pdf', kwargs={"object_type": RegistryObjectType.KEYSET}),
    path('verified-record-statement-pdf/nsset/(<handle>)/', ServeRecordStatementView.as_view(),
         name='record_statement_pdf', kwargs={"object_type": RegistryObjectType.NSSET}),
]

==> fred_webwhois-3.1.3-py3-none-any.whl: webwhois/urls.py <==
#
# Copyright (C) 2015-2023  CZ.NIC, z. s. p. o.
#
# This file is part of FRED.
#
# FRED is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# FRED is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with FRED.  If not, see <https://www.gnu.org/licenses/>.
#
from django.urls import path
from django.views.i18n import JavaScriptCatalog
from fred_types import RegistryObjectType

from webwhois.views import (BlockObjectFormView, ContactDetailView, DomainDetailView, DownloadEvalFileView,
                            EmailInRegistryView, KeysetDetailView, NssetDetailView, PersonalInfoFormView,
                            PublicResponseNotFoundView, PublicResponsePdfView, PublicResponseView, RegistrarDetailView,
                            RegistrarListView, ResolveHandleTypeView, ScanResultsView, SendPasswordFormView,
                            ServeRecordStatementView, UnblockObjectFormView, WhoisFormView)

app_name = 'webwhois'
urlpatterns = [
    path('', WhoisFormView.as_view(), name='form_whois'),
    path('jsi18n/<packages>/', JavaScriptCatalog.as_view(), name='jsi18n'),
    path('object/<handle>/', ResolveHandleTypeView.as_view(), name='registry_object_type'),
    path('contact/<handle>/', ContactDetailView.as_view(), name='detail_contact'),
    path('nsset/<handle>/', NssetDetailView.as_view(), name='detail_nsset'),
    path('keyset/<handle>/', KeysetDetailView.as_view(), name='detail_keyset'),
    path('domain/<handle>/', DomainDetailView.as_view(), name='detail_domain'),
    path('domain/<handle>/scan-results/', ScanResultsView.as_view(), name='scan_results'),
    path('registrar/<handle>/', RegistrarDetailView.as_view(), name='detail_registrar'),
    path('registrars/', RegistrarListView.as_view(), name='registrars'),
    path('registrar-download-evaluation-file/<handle>/', DownloadEvalFileView.as_view(),
         name='download_evaluation_file'),
    path('send-password/', SendPasswordFormView.as_view(), name='form_send_password'),
    path('personal-info/', PersonalInfoFormView.as_view(), name='form_personal_info'),
    path('block-object/', BlockObjectFormView.as_view(), name='form_block_object'),
    path('unblock-object/', UnblockObjectFormView.as_view(), name='form_unblock_object'),
    path('public-response/<public_key>/', PublicResponseView.as_view(), name='public_response'),
    path('public-response/<public_key>/pdf/', PublicResponsePdfView.as_view(), name='public_response_pdf'),
    path('response-not-found/<public_key>/', PublicResponseNotFoundView.as_view(), name='response_not_found'),
    path('email-in-registry/<public_key>/', EmailInRegistryView.as_view(), name='email_in_registry_response'),
    path('verified-record-statement-pdf/contact/<handle>/', ServeRecordStatementView.as_view(),
         name='record_statement_pdf', kwargs={"object_type": RegistryObjectType.CONTACT}),
    path('verified-record-statement-pdf/domain/<handle>/', ServeRecordStatementView.as_view(),
         name='record_statement_pdf', kwargs={"object_type": RegistryObjectType.DOMAIN}),
    path('verified-record-statement-pdf/keyset/<handle>/', ServeRecordStatementView.as_view(),
         name='record_statement_pdf', kwargs={"object_type": RegistryObjectType.KEYSET}),
    path('verified-record-statement-pdf/nsset/<handle>/', ServeRecordStatementView.as_view(),
         name='record_statement_pdf', kwargs={"object_type": RegistryObjectType.NSSET}),
]
